pub struct ScopeRegistry { /* private fields */ }Expand description
Definition registry that rejects duplicate identifiers and unknown client requests.
Implementations
Sourceimpl ScopeRegistry
impl ScopeRegistry
Sourcepub fn register(
&mut self,
resolver: Arc<dyn ScopeResolver>,
) -> Result<(), ScopeError>
pub fn register( &mut self, resolver: Arc<dyn ScopeResolver>, ) -> Result<(), ScopeError>
Registers one definition.
Errors
Returns ScopeError::DuplicateDefinition instead of silently replacing policy.
Sourcepub async fn resolve(
&self,
principal: ScopePrincipal,
request: &ScopeRequest,
) -> Result<ResolvedScope, ScopeError>
pub async fn resolve( &self, principal: ScopePrincipal, request: &ScopeRequest, ) -> Result<ResolvedScope, ScopeError>
Resolves and validates a requested scope after authentication.
Errors
Returns a typed request, lookup, authorization, or descriptor error.