pub trait ScopeResourceAuthorizer<R>: Send + Sync {
// Required method
fn authorized(
&self,
principal: ScopePrincipal,
scope: &ResolvedScope,
resource: &R,
) -> bool;
}Expand description
Authorization hook for blobs, integrity manifests, search indexes, or other scope-bound resources. Possessing a stale resource identifier never grants access by itself.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".